@@ -17,6 +17,8 @@ type Option struct {
 	option.ReportOption
 	option.CacheOption
 	option.ConfigOption
+	option.RemoteOption
+	option.SbomOption
 
 	// We don't want to allow disabled analyzers to be passed by users,
 	// but it differs depending on scanning modes.
@@ -38,6 +40,8 @@ func NewOption(c *cli.Context) (Option, error) {
 		ReportOption:   option.NewReportOption(c),
 		CacheOption:    option.NewCacheOption(c),
 		ConfigOption:   option.NewConfigOption(c),
+		RemoteOption:   option.NewRemoteOption(c),
+		SbomOption:     option.NewSbomOption(c),
 	}, nil
 }
 
@@ -55,7 +59,6 @@ func (c *Option) Init() error {
 	if err := c.ArtifactOption.Init(c.Context, c.Logger); err != nil {
 		return err
 	}
-
 	return nil
 }
 
@@ -69,6 +72,10 @@ func (c *Option) initPreScanOptions() error {
 	if err := c.CacheOption.Init(); err != nil {
 		return err
 	}
+	if err := c.SbomOption.Init(c.Context, c.Logger); err != nil {
+		return err
+	}
+	c.RemoteOption.Init(c.Logger)
 	return nil
 }
 
