@@ -6,6 +6,7 @@ import (
 	"os"
 
 	"github.com/urfave/cli/v2"
+	"golang.org/x/exp/slices"
 	"golang.org/x/xerrors"
 
 	"github.com/aquasecurity/fanal/analyzer"
@@ -13,9 +14,11 @@ import (
 	"github.com/aquasecurity/fanal/artifact"
 	"github.com/aquasecurity/fanal/cache"
 	"github.com/aquasecurity/trivy-db/pkg/db"
+	tcache "github.com/aquasecurity/trivy/pkg/cache"
 	"github.com/aquasecurity/trivy/pkg/commands/operation"
 	"github.com/aquasecurity/trivy/pkg/log"
 	pkgReport "github.com/aquasecurity/trivy/pkg/report"
+	"github.com/aquasecurity/trivy/pkg/rpc/client"
 	"github.com/aquasecurity/trivy/pkg/scanner"
 	"github.com/aquasecurity/trivy/pkg/types"
 	"github.com/aquasecurity/trivy/pkg/utils"
@@ -25,9 +28,26 @@ const defaultPolicyNamespace = "appshield"
 
 var errSkipScan = errors.New("skip subsequent processes")
 
+type scannerConfig struct {
+	// e.g. image name and file path
+	Target string
+
+	// Cache
+	ArtifactCache      cache.ArtifactCache
+	LocalArtifactCache cache.LocalArtifactCache
+
+	// Client/Server options
+	RemoteOption client.ScannerOption
+
+	// Artifact options
+	ArtifactOption artifact.Option
+
+	// Misconfiguration scanning options
+	MisconfOption config.ScannerOption
+}
+
 // InitializeScanner defines the initialize function signature of scanner
-type InitializeScanner func(context.Context, string, cache.ArtifactCache, cache.LocalArtifactCache, bool,
-	artifact.Option, config.ScannerOption) (scanner.Scanner, func(), error)
+type InitializeScanner func(context.Context, scannerConfig) (scanner.Scanner, func(), error)
 
 // InitCache defines cache initializer
 type InitCache func(c Option) (cache.Cache, error)
@@ -37,7 +57,11 @@ func Run(ctx context.Context, opt Option, initializeScanner InitializeScanner, i
 	ctx, cancel := context.WithTimeout(ctx, opt.Timeout)
 	defer cancel()
 
-	return runWithTimeout(ctx, opt, initializeScanner, initCache)
+	err := runWithTimeout(ctx, opt, initializeScanner, initCache)
+	if xerrors.Is(err, context.DeadlineExceeded) {
+		log.Logger.Warn("Increase --timeout value")
+	}
+	return err
 }
 
 func runWithTimeout(ctx context.Context, opt Option, initializeScanner InitializeScanner, initCache InitCache) error {
@@ -54,8 +78,8 @@ func runWithTimeout(ctx context.Context, opt Option, initializeScanner Initializ
 	}
 	defer cacheClient.Close()
 
-	// When scanning config files, it doesn't need to download the vulnerability database.
-	if utils.StringInSlice(types.SecurityCheckVulnerability, opt.SecurityChecks) {
+	// When scanning config files or running as client mode, it doesn't need to download the vulnerability database.
+	if opt.RemoteAddr == "" && slices.Contains(opt.SecurityChecks, types.SecurityCheckVulnerability) {
 		if err = initDB(opt); err != nil {
 			if errors.Is(err, errSkipScan) {
 				return nil
@@ -92,7 +116,14 @@ func runWithTimeout(ctx context.Context, opt Option, initializeScanner Initializ
 	return nil
 }
 
-func initFSCache(c Option) (cache.Cache, error) {
+func initCache(c Option) (cache.Cache, error) {
+	// client/server mode
+	if c.RemoteAddr != "" {
+		remoteCache := tcache.NewRemoteCache(c.RemoteAddr, c.CustomHeaders, c.Insecure)
+		return tcache.NopCache(remoteCache), nil
+	}
+
+	// standalone mode
 	utils.SetCacheDir(c.CacheDir)
 	cache, err := operation.NewCache(c.CacheOption)
 	if err != nil {
@@ -120,7 +151,7 @@ func initFSCache(c Option) (cache.Cache, error) {
 func initDB(c Option) error {
 	// download the database file
 	noProgress := c.Quiet || c.NoProgress
-	if err := operation.DownloadDB(c.AppVersion, c.CacheDir, noProgress, c.SkipDBUpdate); err != nil {
+	if err := operation.DownloadDB(c.AppVersion, c.CacheDir, c.DBRepository, noProgress, c.SkipDBUpdate); err != nil {
 		return err
 	}
 
@@ -159,7 +190,7 @@ func disabledAnalyzers(opt Option) []analyzer.Type {
 	}
 
 	// Don't analyze programming language packages when not running in 'library' mode
-	if !utils.StringInSlice(types.VulnTypeLibrary, opt.VulnType) {
+	if !slices.Contains(opt.VulnType, types.VulnTypeLibrary) {
 		analyzers = append(analyzers, analyzer.TypeLanguages...)
 	}
 
@@ -167,7 +198,7 @@ func disabledAnalyzers(opt Option) []analyzer.Type {
 }
 
 func scan(ctx context.Context, opt Option, initializeScanner InitializeScanner, cacheClient cache.Cache) (
-	pkgReport.Report, error) {
+	types.Report, error) {
 	target := opt.Target
 	if opt.Input != "" {
 		target = opt.Input
@@ -181,13 +212,13 @@ func scan(ctx context.Context, opt Option, initializeScanner InitializeScanner,
 	}
 	log.Logger.Debugf("Vulnerability type:  %s", scanOptions.VulnType)
 
-	// ScannerOptions is filled only when config scanning is enabled.
+	// ScannerOption is filled only when config scanning is enabled.
 	var configScannerOptions config.ScannerOption
-	if utils.StringInSlice(types.SecurityCheckConfig, opt.SecurityChecks) {
+	if slices.Contains(opt.SecurityChecks, types.SecurityCheckConfig) {
 		noProgress := opt.Quiet || opt.NoProgress
 		builtinPolicyPaths, err := operation.InitBuiltinPolicies(ctx, opt.CacheDir, noProgress, opt.SkipPolicyUpdate)
 		if err != nil {
-			return pkgReport.Report{}, xerrors.Errorf("failed to initialize built-in policies: %w", err)
+			return types.Report{}, xerrors.Errorf("failed to initialize built-in policies: %w", err)
 		}
 
 		configScannerOptions = config.ScannerOption{
@@ -199,37 +230,49 @@ func scan(ctx context.Context, opt Option, initializeScanner InitializeScanner,
 		}
 	}
 
-	artifactOpt := artifact.Option{
-		DisabledAnalyzers: disabledAnalyzers(opt),
-		SkipFiles:         opt.SkipFiles,
-		SkipDirs:          opt.SkipDirs,
-		InsecureSkipTLS:   opt.Insecure,
-		Offline:           opt.OfflineScan,
-		Quiet:             opt.Quiet,
-	}
-
-	s, cleanup, err := initializeScanner(ctx, target, cacheClient, cacheClient, opt.Insecure, artifactOpt, configScannerOptions)
+	s, cleanup, err := initializeScanner(ctx, scannerConfig{
+		Target:             target,
+		ArtifactCache:      cacheClient,
+		LocalArtifactCache: cacheClient,
+		RemoteOption: client.ScannerOption{
+			RemoteURL:     opt.RemoteAddr,
+			CustomHeaders: opt.CustomHeaders,
+			Insecure:      opt.Insecure,
+		},
+		ArtifactOption: artifact.Option{
+			DisabledAnalyzers: disabledAnalyzers(opt),
+			SkipFiles:         opt.SkipFiles,
+			SkipDirs:          opt.SkipDirs,
+			InsecureSkipTLS:   opt.Insecure,
+			Offline:           opt.OfflineScan,
+			NoProgress:        opt.NoProgress || opt.Quiet,
+		},
+		MisconfOption: configScannerOptions,
+	})
 	if err != nil {
-		return pkgReport.Report{}, xerrors.Errorf("unable to initialize a scanner: %w", err)
+		return types.Report{}, xerrors.Errorf("unable to initialize a scanner: %w", err)
 	}
 	defer cleanup()
 
 	report, err := s.ScanArtifact(ctx, scanOptions)
 	if err != nil {
-		return pkgReport.Report{}, xerrors.Errorf("image scan failed: %w", err)
+		return types.Report{}, xerrors.Errorf("image scan failed: %w", err)
 	}
 	return report, nil
 }
 
-func filter(ctx context.Context, opt Option, report pkgReport.Report) (pkgReport.Report, error) {
+func filter(ctx context.Context, opt Option, report types.Report) (types.Report, error) {
 	resultClient := initializeResultClient()
 	results := report.Results
 	for i := range results {
-		resultClient.FillVulnerabilityInfo(results[i].Vulnerabilities, results[i].Type)
+		// Fill vulnerability info only in standalone mode
+		if opt.RemoteAddr == "" {
+			resultClient.FillVulnerabilityInfo(results[i].Vulnerabilities, results[i].Type)
+		}
 		vulns, misconfSummary, misconfs, err := resultClient.Filter(ctx, results[i].Vulnerabilities, results[i].Misconfigurations,
 			opt.Severities, opt.IgnoreUnfixed, opt.IncludeNonFailures, opt.IgnoreFile, opt.IgnorePolicy)
 		if err != nil {
-			return pkgReport.Report{}, xerrors.Errorf("unable to filter vulnerabilities: %w", err)
+			return types.Report{}, xerrors.Errorf("unable to filter vulnerabilities: %w", err)
 		}
 		results[i].Vulnerabilities = vulns
 		results[i].Misconfigurations = misconfs
@@ -238,7 +281,7 @@ func filter(ctx context.Context, opt Option, report pkgReport.Report) (pkgReport
 	return report, nil
 }
 
-func exit(c Option, results pkgReport.Results) {
+func exit(c Option, results types.Results) {
 	if c.ExitCode != 0 && results.Failed() {
 		os.Exit(c.ExitCode)
 	}
