@@ -1,6 +1,8 @@
 package types
 
-import "github.com/aquasecurity/trivy/pkg/utils"
+import (
+	"golang.org/x/exp/slices"
+)
 
 // VulnType represents vulnerability type
 type VulnType = string
@@ -35,7 +37,7 @@ var (
 
 // NewVulnType returns an instance of VulnType
 func NewVulnType(s string) VulnType {
-	if utils.StringInSlice(s, vulnTypes) {
+	if slices.Contains(vulnTypes, s) {
 		return s
 	}
 	return VulnTypeUnknown
@@ -43,7 +45,7 @@ func NewVulnType(s string) VulnType {
 
 // NewSecurityCheck returns an instance of SecurityCheck
 func NewSecurityCheck(s string) SecurityCheck {
-	if utils.StringInSlice(s, securityChecks) {
+	if slices.Contains(securityChecks, s) {
 		return s
 	}
 	return SecurityCheckUnknown
